@@ -136,7 +136,9 @@ class DeprecatedMixin(BaseChecker):
             inf = safe_infer(children[0].func)
         else:
             inf = safe_infer(children[0])
-        qname = inf.qname() if inf else None
+        if not isinstance(inf, (nodes.ClassDef, nodes.FunctionDef)):
+            return
+        qname = inf.qname()
         if qname in self.deprecated_decorators():
             self.add_message("deprecated-decorator", node=node, args=qname)
 
@@ -236,7 +238,6 @@ class DeprecatedMixin(BaseChecker):
 
         This method should be called from the checker implementing this mixin.
         """
-
         # Reject nodes which aren't of interest to us.
         if not isinstance(inferred, ACCEPTABLE_NODES):
             return
@@ -272,7 +273,6 @@ class DeprecatedMixin(BaseChecker):
         self, node: nodes.NodeNG, mod_name: str, class_names: Iterable[str]
     ) -> None:
         """Checks if the class is deprecated."""
-
         for class_name in class_names:
             if class_name in self.deprecated_classes(mod_name):
                 self.add_message(
@@ -281,7 +281,6 @@ class DeprecatedMixin(BaseChecker):
 
     def check_deprecated_class_in_call(self, node: nodes.Call) -> None:
         """Checks if call the deprecated class."""
-
         if isinstance(node.func, nodes.Attribute) and isinstance(
             node.func.expr, nodes.Name
         ):
