@@ -10,7 +10,6 @@ from typing import Any
 
 from astroid import nodes
 
-from pylint.constants import IS_PYPY, PY39_PLUS
 from pylint.testutils.global_test_linter import linter
 from pylint.testutils.output_line import MessageTest
 from pylint.testutils.unittest_linter import UnittestLinter
@@ -41,7 +40,7 @@ class CheckerTestCase:
     @contextlib.contextmanager
     def assertAddsMessages(
         self, *messages: MessageTest, ignore_position: bool = False
-    ) -> Generator[None, None, None]:
+    ) -> Generator[None]:
         """Assert that exactly the given method adds the given messages.
 
         The list of messages must exactly match *all* the messages added by the
@@ -76,9 +75,8 @@ class CheckerTestCase:
 
             assert expected_msg.line == gotten_msg.line, msg
             assert expected_msg.col_offset == gotten_msg.col_offset, msg
-            if not IS_PYPY or PY39_PLUS:
-                assert expected_msg.end_line == gotten_msg.end_line, msg
-                assert expected_msg.end_col_offset == gotten_msg.end_col_offset, msg
+            assert expected_msg.end_line == gotten_msg.end_line, msg
+            assert expected_msg.end_col_offset == gotten_msg.end_col_offset, msg
 
     def walk(self, node: nodes.NodeNG) -> None:
         """Recursive walk on the given node."""
