@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Some various utilities and helper classes, most of them used in the
 main pylint class.
@@ -14,13 +14,12 @@ from pylint.utils.utils import (
     HAS_ISORT_5,
     IsortDriver,
     _check_csv,
-    _format_option_value,
+    _check_regexp_csv,
     _splitstrip,
     _unquote,
     decoding_stream,
     diff_string,
     format_section,
-    get_global_option,
     get_module_and_frameid,
     get_rst_section,
     get_rst_title,
@@ -34,14 +33,13 @@ __all__ = [
     "HAS_ISORT_5",
     "IsortDriver",
     "_check_csv",
-    "_format_option_value",
+    "_check_regexp_csv",
     "_splitstrip",
     "_unquote",
     "decoding_stream",
     "diff_string",
     "FileState",
     "format_section",
-    "get_global_option",
     "get_module_and_frameid",
     "get_rst_section",
     "get_rst_title",
