@@ -7,7 +7,7 @@ from __future__ import annotations
 import collections
 from collections import defaultdict
 from collections.abc import Iterator
-from typing import TYPE_CHECKING, Dict, Literal
+from typing import TYPE_CHECKING, Literal
 
 from astroid import nodes
 
@@ -21,7 +21,7 @@ if TYPE_CHECKING:
     from pylint.message import MessageDefinition, MessageDefinitionStore
 
 
-MessageStateDict = Dict[str, Dict[int, bool]]
+MessageStateDict = dict[str, dict[int, bool]]
 
 
 class FileState:
@@ -38,9 +38,9 @@ class FileState:
         self.base_name = modname
         self._module_msgs_state: MessageStateDict = {}
         self._raw_module_msgs_state: MessageStateDict = {}
-        self._ignored_msgs: defaultdict[
-            tuple[str, int], set[int]
-        ] = collections.defaultdict(set)
+        self._ignored_msgs: defaultdict[tuple[str, int], set[int]] = (
+            collections.defaultdict(set)
+        )
         self._suppression_mapping: dict[tuple[str, int], int] = {}
         self._module = node
         if node:
